@@ -1,6 +1,6 @@
 # Copyright 2015-2023 Province of British Columbia
 # Copyright 2021 Environment and Climate Change Canada
-# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Copyright 2023-2024 Australian Government Department of Climate Change,
 # Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
@@ -58,10 +58,13 @@ ssd_hp.fitdists <- function(
 
   chk_unused(...)
 
-
   fix_weights <- ci_method %in% c("weighted_samples", "multi_fixed")
   multi_ci <- ci_method %in% c("multi_free", "multi_fixed")
 
+  if(length(x) == 1L) {
+    average <- FALSE
+  }
+  
   hcp <- ssd_hcp_fitdists(
     x = x,
     value = conc,
