@@ -1,6 +1,6 @@
 # Copyright 2015-2023 Province of British Columbia
 # Copyright 2021 Environment and Climate Change Canada
-# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Copyright 2023-2024 Australian Government Department of Climate Change,
 # Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
@@ -33,9 +33,6 @@ ssd_pmulti <- function(
     gompertz.weight = 0,
     gompertz.location = 1,
     gompertz.shape = 1,
-    invpareto.weight = 0,
-    invpareto.shape = 3,
-    invpareto.scale = 1,
     lgumbel.weight = 0,
     lgumbel.locationlog = 0,
     lgumbel.scalelog = 1,
@@ -73,9 +70,6 @@ ssd_pmulti <- function(
     gompertz.weight = gompertz.weight,
     gompertz.location = gompertz.location,
     gompertz.shape = gompertz.shape,
-    invpareto.weight = invpareto.weight,
-    invpareto.shape = invpareto.shape,
-    invpareto.scale = invpareto.scale,
     lgumbel.weight = lgumbel.weight,
     lgumbel.locationlog = lgumbel.locationlog,
     lgumbel.scalelog = lgumbel.scalelog,
@@ -122,9 +116,6 @@ ssd_qmulti <- function(
     gompertz.weight = 0,
     gompertz.location = 1,
     gompertz.shape = 1,
-    invpareto.weight = 0,
-    invpareto.shape = 3,
-    invpareto.scale = 1,
     lgumbel.weight = 0,
     lgumbel.locationlog = 0,
     lgumbel.scalelog = 1,
@@ -162,9 +153,6 @@ ssd_qmulti <- function(
     gompertz.weight = gompertz.weight,
     gompertz.location = gompertz.location,
     gompertz.shape = gompertz.shape,
-    invpareto.weight = invpareto.weight,
-    invpareto.shape = invpareto.shape,
-    invpareto.scale = invpareto.scale,
     lgumbel.weight = lgumbel.weight,
     lgumbel.locationlog = lgumbel.locationlog,
     lgumbel.scalelog = lgumbel.scalelog,
@@ -212,9 +200,6 @@ ssd_rmulti <- function(
     gompertz.weight = 0,
     gompertz.location = 1,
     gompertz.shape = 1,
-    invpareto.weight = 0,
-    invpareto.shape = 3,
-    invpareto.scale = 1,
     lgumbel.weight = 0,
     lgumbel.locationlog = 0,
     lgumbel.scalelog = 1,
@@ -252,9 +237,6 @@ ssd_rmulti <- function(
     gompertz.weight = gompertz.weight,
     gompertz.location = gompertz.location,
     gompertz.shape = gompertz.shape,
-    invpareto.weight = invpareto.weight,
-    invpareto.shape = invpareto.shape,
-    invpareto.scale = invpareto.scale,
     lgumbel.weight = lgumbel.weight,
     lgumbel.locationlog = lgumbel.locationlog,
     lgumbel.scalelog = lgumbel.scalelog,
@@ -412,9 +394,6 @@ pmulti_ssd <- function(
     gompertz.weight,
     gompertz.location,
     gompertz.shape,
-    invpareto.weight,
-    invpareto.shape,
-    invpareto.scale,
     lgumbel.weight,
     lgumbel.locationlog,
     lgumbel.scalelog,
@@ -451,9 +430,6 @@ pmulti_ssd <- function(
       gompertz.weight = gompertz.weight,
       gompertz.location = gompertz.location,
       gompertz.shape = gompertz.shape,
-      invpareto.weight = invpareto.weight,
-      invpareto.shape = invpareto.shape,
-      invpareto.scale = invpareto.scale,
       lgumbel.weight = lgumbel.weight,
       lgumbel.locationlog = lgumbel.locationlog,
       lgumbel.scalelog = lgumbel.scalelog,
@@ -496,9 +472,6 @@ qmulti_ssd <- function(
     gompertz.weight,
     gompertz.location,
     gompertz.shape,
-    invpareto.weight,
-    invpareto.shape,
-    invpareto.scale,
     lgumbel.weight,
     lgumbel.locationlog,
     lgumbel.scalelog,
@@ -535,9 +508,6 @@ qmulti_ssd <- function(
       gompertz.weight = gompertz.weight,
       gompertz.location = gompertz.location,
       gompertz.shape = gompertz.shape,
-      invpareto.weight = invpareto.weight,
-      invpareto.shape = invpareto.shape,
-      invpareto.scale = invpareto.scale,
       lgumbel.weight = lgumbel.weight,
       lgumbel.locationlog = lgumbel.locationlog,
       lgumbel.scalelog = lgumbel.scalelog,
@@ -580,9 +550,6 @@ rmulti_ssd <- function(
     gompertz.weight,
     gompertz.location,
     gompertz.shape,
-    invpareto.weight,
-    invpareto.shape,
-    invpareto.scale,
     lgumbel.weight,
     lgumbel.locationlog,
     lgumbel.scalelog,
@@ -621,9 +588,6 @@ rmulti_ssd <- function(
       gompertz.weight = gompertz.weight,
       gompertz.location = gompertz.location,
       gompertz.shape = gompertz.shape,
-      invpareto.weight = invpareto.weight,
-      invpareto.shape = invpareto.shape,
-      invpareto.scale = invpareto.scale,
       lgumbel.weight = lgumbel.weight,
       lgumbel.locationlog = lgumbel.locationlog,
       lgumbel.scalelog = lgumbel.scalelog,
